/// <reference types="react" />
import { ImageURISource, ImageBackgroundProps } from 'react-native';
export declare type ProgressBarProps = {
    /**
     * If the progress bar will show indeterminate progress by looping an animation infinitely.
     *
     * @default false
     */
    isIndeterminate?: boolean;
    /**
     * Duration to animate changes in milliseconds.
     *
     * @default isIndeterminate ? 1000 : 500
     */
    duration?: number;
    /**
     * If the bar should animate between values.
     *
     * @default false
     */
    isAnimated?: boolean;
    /**
     * The progress value (between 0 and 1).
     *
     * @default 0
     */
    progress?: number;
    /**
     * The tint color of the progress bar itself.
     *
     * @default #007aff
     */
    color?: string;
    /**
     * The tint color of the progress bar track.
     *
     * @default transparent
     */
    trackColor?: string;
    /**
     * A stretchable image to display as the progress bar.
     */
    progressImage?: ImageURISource | ImageURISource[];
    /**
     * A stretchable image to display behind the progress bar.
     */
    trackImage?: ImageURISource | ImageURISource[];
    /**
     * Height of the loading indicator.
     *
     * @default 7
     */
    height?: number;
    /**
     * Border radius of the loading indicator.
     *
     * @default height / 2
     */
    borderRadius?: number;
    /**
     * Style for the loading indicator container view.
     */
    style?: ImageBackgroundProps['style'];
};
declare function ProgressBar({ isIndeterminate, duration, isAnimated, progress, height, borderRadius, color, trackColor, style, trackImage, progressImage, }: ProgressBarProps): JSX.Element;
export default ProgressBar;
