import * as React from 'react';
import { ImageBackground, Platform, StyleSheet, } from 'react-native';
import Animated, { 
// @ts-ignore: always isn't defined in the types
always, block, Extrapolate, interpolate, multiply, set, } from 'react-native-reanimated';
import { clamp, loop, timing, useValue } from 'react-native-redash';
const minProgress = 0;
const maxProgress = 1;
function useCode(nodeFactory, dependencies) {
    if (!(React.useEffect instanceof Function))
        return;
    // @ts-ignore
    React.useEffect(() => {
        // check and correct 1st parameter
        if (!(nodeFactory instanceof Function)) {
            console.warn('useCode() first argument should be a function that returns an animation node.');
            const node = nodeFactory;
            nodeFactory = () => node;
        }
        let node = nodeFactory();
        if (node) {
            // allow factory to return array
            if (node instanceof Array)
                node = block(node);
            const animatedAlways = always(node);
            animatedAlways.__attach();
            // todo: upstream this
            if (Platform.OS === 'web') {
                animatedAlways.__onEvaluate();
            }
            // return undo function
            return () => animatedAlways.__detach();
        }
    }, dependencies);
}
function ProgressBar({ isIndeterminate = false, duration = isIndeterminate ? 1000 : 500, isAnimated = false, progress = isIndeterminate ? 0.5 : 0, height = 7, borderRadius = height * 0.5, 
// Default iOS blue
color = '#007aff', trackColor = 'transparent', style, trackImage, progressImage, }) {
    const [width, setWidth] = React.useState(0);
    const progressValue = useValue(isAnimated ? 0 : progress);
    const indeterminateValue = useValue(0);
    const animatedWidth = interpolate(clamp(progressValue, minProgress, maxProgress), {
        inputRange: [minProgress, maxProgress],
        outputRange: [0, width],
        extrapolate: Extrapolate.CLAMP,
    });
    useCode(() => {
        if (isAnimated) {
            return set(progressValue, timing({
                from: progressValue,
                to: progress,
                duration,
            }));
        }
        else {
            return set(progressValue, progress);
        }
    }, [progress]);
    useCode(() => {
        if (isIndeterminate) {
            const loopingIndeterminateValue = loop({
                autoStart: true,
                boomerang: false,
                duration,
            });
            return set(indeterminateValue, loopingIndeterminateValue);
        }
        const animatedIndeterminateValue = timing({
            from: indeterminateValue,
            to: 0,
        });
        return set(indeterminateValue, animatedIndeterminateValue);
    }, [isIndeterminate]);
    // todo: web has a bug where the reanimated Animated.View style is not updating unless this is an animated value.
    let translateX = useValue(0);
    if (isIndeterminate) {
        translateX = interpolate(indeterminateValue, {
            inputRange: [0, 1],
            outputRange: [multiply(-1, animatedWidth), width],
        });
    }
    return (React.createElement(ImageBackground, { onLayout: (e) => {
            setWidth(e.nativeEvent.layout.width);
        }, resizeMode: 'stretch', style: [
            styles.container,
            {
                height,
                borderRadius,
                backgroundColor: trackColor,
            },
            style,
        ], 
        // @ts-ignore
        source: trackImage },
        React.createElement(Animated.Image, { style: [
                styles.bar,
                {
                    width: animatedWidth,
                    transform: [
                        {
                            translateX,
                        },
                    ],
                    backgroundColor: color,
                    borderRadius,
                },
            ], 
            // @ts-ignore
            source: progressImage })));
}
const styles = StyleSheet.create({
    container: {
        width: '100%',
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: 'transparent',
        overflow: 'hidden',
    },
    bar: {
        resizeMode: 'stretch',
        left: 0,
        position: 'absolute',
        height: '100%',
    },
});
export default ProgressBar;
//# sourceMappingURL=Bar.js.map